Crate algebraeon_nzq

Crate algebraeon_nzq 

Modules

combinatorics
traits
Traits for operations on numbers not covered by the standard library.

Structs

Integer
Represent an integer {…, -2, -1, 0, 1, 2, …}
IntegerCanonicalStructure
Natural
Represents a natural number {0, 1, 2, …}
NaturalCanonicalStructure
Rational
Represent a rational number - a number of the form a/b where a is an integer and b is a non-zero integer.
RationalCanonicalStructure
Rng
For generating pseudo-random numbers.

Functions

choose
gcd
The greatest common divisor of x and y
lcm
The least common multiple of x and y
primes
Return an iterator generating all prime numbers.